#ifndef TEST_STATS_EXP_HPP
#define TEST_STATS_EXP_HPP

#include <boost/math/distributions/exponential.hpp>
#include <boost/math/policies/policy.hpp>
#include <boost/random/exponential_distribution.hpp>
#include <boost/random/variate_generator.hpp>


namespace test { namespace stats {

template <class RealType = double, class Policy = ::boost::math::policies::policy<> >
class exponential_distribution: public ::boost::math::exponential_distribution<RealType,Policy>
{
public:
	typedef RealType value_type;
	typedef Policy policy_type;

	exponential_distribution(RealType lambda = 1)
		: ::boost::math::exponential_distribution<RealType,Policy>(lambda)
	{
	}
};
typedef exponential_distribution<double> exponential;

// Global Accessors

template <class RealType, class Policy>
inline RealType mean(const exponential_distribution<RealType, Policy>& dist)
{
	return ::boost::math::mean(dist);
}

template <class RealType, class Policy>
inline RealType standard_deviation(const exponential_distribution<RealType, Policy>& dist)
{
	return ::boost::math::standard_deviation(dist);
}

template <class RealType, class Policy>
inline RealType variance(const exponential_distribution<RealType, Policy>& dist)
{
	return ::boost::math::variance(dist);
}

template <typename RealType, typename Policy, typename Generator>
inline RealType rand(const exponential_distribution<RealType,Policy>& dist, Generator& rng)
{
	typedef typename ::boost::exponential_distribution<RealType> rdist_type;
	typedef typename ::boost::variate_generator<Generator&, rdist_type> variate_type;
	return variate_type(rng, rdist_type(dist.lambda()))();
}

}} // test::stats

#endif // TEST_STATS_EXP_HPP
