#ifndef TEST_STATS_LNORM_HPP
#define TEST_STATS_LNORM_HPP

#include <boost/math/distributions/lognormal.hpp>
#include <boost/math/policies/policy.hpp>
#include <boost/random/lognormal_distribution.hpp>
#include <boost/random/variate_generator.hpp>

namespace test { namespace stats {


template <class RealType = double, class Policy = ::boost::math::policies::policy<> >
class lognormal_distribution: public ::boost::math::lognormal_distribution<RealType,Policy>
{
public:
	typedef RealType value_type;
	typedef Policy policy_type;

	lognormal_distribution(RealType location = 0, RealType scale = 1)
		: ::boost::math::lognormal_distribution<RealType,Policy>(location,scale)
	{
	}
};

typedef lognormal_distribution<double> lognormal;


// Global Accessors


template <typename RealType, typename Policy>
inline RealType mean(const lognormal_distribution<RealType,Policy>& dist)
{
	return ::boost::math::mean(dist);
}

template <typename RealType, typename Policy>
inline RealType standard_deviation(const lognormal_distribution<RealType,Policy>& dist)
{
	return ::boost::math::standard_deviation(dist);
}

template <typename RealType, typename Policy>
inline RealType variance(const lognormal_distribution<RealType,Policy>& dist)
{
	return ::boost::math::variance(dist);
}

template <typename RealType, typename Policy, typename Generator>
inline RealType rand(const lognormal_distribution<RealType,Policy>& dist, Generator& rng)
{
	typedef typename boost::lognormal_distribution<RealType> rdist_type;
	typedef typename boost::variate_generator<Generator&, rdist_type> variate_type;
	return variate_type(
				rng,
				rdist_type(
					::boost::math::mean(dist),
					::boost::math::standard_deviation(dist)
				)
	)();
}

}} // test::stats

#endif // TEST_STATS_LNORM_HPP
